===============================
srwpy
===============================

.. image:: https://img.shields.io/travis/srwpy/srwpy.svg
        :target: https://travis-ci.org/srwpy/srwpy

.. image:: https://ci.appveyor.com/api/projects/status/8e0gwxyn27ookg8s?svg=true
        :target: https://ci.appveyor.com/project/mrakitin/srwpy

.. image:: https://img.shields.io/pypi/v/srwpy.svg
        :target: https://pypi.python.org/pypi/srwpy


Synchrotron Radiation Workshop

Based on:

* https://github.com/ochubar/SRW for the source code
* https://github.com/NSLS-II/scientific-python-cookiecutter for the structure and features


Licensing and documentation:

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://srwpy.github.io/srwpy.

Compilation in Windows
----------------------
* install OASYS
* install Visual Studio 2019 with c++ tools
* Start the Visual Studio Command Prompt (check then "where msbuild")
* Activate miniconda "c:\\miniconda3\\Scripts\\activate"
* python setup.py bdist_wheel
* python -m twine upload dist\*


Features
--------

* TODO
